summaryrefslogtreecommitdiffstats
path: root/src/2geom/interval.h
diff options
context:
space:
mode:
authorJohan B. C. Engelen <jbc.engelen@swissonline.ch>2008-07-25 21:03:44 +0000
committerjohanengelen <johanengelen@users.sourceforge.net>2008-07-25 21:03:44 +0000
commit57d418b27cd2f4b75de1672c0a6e58fe2e5546c9 (patch)
treea5b44b406145087d79d14033b080e6918befc0d3 /src/2geom/interval.h
parentcopyedit (diff)
downloadinkscape-57d418b27cd2f4b75de1672c0a6e58fe2e5546c9.tar.gz
inkscape-57d418b27cd2f4b75de1672c0a6e58fe2e5546c9.zip
update to 2geom rev. 1507
(bzr r6416)
Diffstat (limited to 'src/2geom/interval.h')
-rw-r--r--src/2geom/interval.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/2geom/interval.h b/src/2geom/interval.h
index 9887c044f..74e03aec9 100644
--- a/src/2geom/interval.h
+++ b/src/2geom/interval.h
@@ -44,16 +44,16 @@
namespace Geom {
/* Although an Interval where _b[0] > _b[1] is considered empty, for proper functioning of other methods,
* a proper empty Interval is [+COORD_HUGE, -COORD_HUGE]. Then, expandTo(p) will set the interval to [p,p].
*/
class Interval {
private:
Coord _b[2];
public:
// The default constructor creates an empty interval, that ranges from +COORD_HUGE to -COORD_HUGE.
// Doing an expandTo(p) on this empty interval will correctly set the whole interval to [p,p].
- explicit Interval() { _b[0] = +COORD_HUGE; _b[1] = -COORD_HUGE; }
+ explicit Interval() { _b[0] = +infinity(); _b[1] = -infinity(); }
explicit Interval(Coord u) { _b[0] = _b[1] = u; }
/* When creating an Interval using the constructor specifying the exact range, the created interval
* will be [u,v] when u<=v ; and will be [v,u] when v < u !!!
@@ -44,16 +44,16 @@
namespace Geom {
/* Although an Interval where _b[0] > _b[1] is considered empty, for proper functioning of other methods,
- * a proper empty Interval is [+COORD_HUGE, -COORD_HUGE]. Then, expandTo(p) will set the interval to [p,p].
+ * a proper empty Interval is [+infinity, -infinity]. Then, expandTo(p) will set the interval to [p,p].
*/
class Interval {
@@ -44,16 +44,16 @@
Coord _b[2];
public:
- // The default constructor creates an empty interval, that ranges from +COORD_HUGE to -COORD_HUGE.
+ // The default constructor creates an empty interval, that ranges from +infinity to -infinity.
// Doing an expandTo(p) on this empty interval will correctly set the whole interval to [p,p].